@@ -1,10 +1,10 @@
 /*************************************************************
- * Unit:    raster            release 0.31                   *
+ * Unit:    raster            release 0.38                   *
  * Purpose: General manipulation n dimensional matrices      *
  *          n = 1, 2 and 3.			             *
  * Modul:   raster.cc                                        *
  * Licency: GPL or LGPL                                      *
- * Copyright: (c) 1998-2024 Jaroslav Fojtik                  *
+ * Copyright: (c) 1998-2025 Jaroslav Fojtik                  *
  *************************************************************/
 #include<stdio.h>
 #include<string.h>
@@ -19,7 +19,7 @@
 #include "ras_prot.h"
 
 
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
  #ifndef _UI64_MAX
   #ifdef __BORLANDC__
    #define _UI64_MAX    18446744073709551615ui64
@@ -68,10 +68,10 @@ void Raster1DAbstract::Erase1DStub(void)
 void Raster1DAbstract::Allocate1D(unsigned NewSize1D)
 {
  if(Data1D!=NULL) 
-   {
+ {
    if(Size1D==NewSize1D) return;	// No reallocation needed.
    free(Data1D); Data1D=NULL;
-   }
+ }
  if(NewSize1D==0) return;
  const unsigned long SzBit = (unsigned long)labs(GetPlanes()) * NewSize1D;
  Data1D = malloc((SzBit+7)/8);
@@ -99,7 +99,7 @@ void Raster1DAbstract::Get(Raster1DAbstract &R1) const
 int i, maxi;
 int shift;
 
- maxi = Size1D>R1.Size1D?Size1D:R1.Size1D;
+ maxi = (Size1D>R1.Size1D) ? Size1D : R1.Size1D;
 
  if(R1.GetPlanes()==GetPlanes())
    {
@@ -126,14 +126,14 @@ int shift;
 
  i = R1.GetPlanes(); 
  shift = GetPlanes();
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
  if(i>32) i=32;
  if(shift>32) shift=32;
 #endif
 
  shift = i - shift;
 
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
  if(shift==0)		// Also used for cropped 64 bit values.
  {
    for(i=0; i<maxi; i++)
@@ -510,6 +510,8 @@ int i;
     case -1:
     case 1: Raster1DAbstract::Set(R1);
 	    return;
+    case 2: Conv2_1((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+	    return;
     case -4:
     case 4: Conv4_1((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
 	    return;
@@ -519,18 +521,13 @@ int i;
     case -16:
     case 16:Conv16_1((uint8_t *)Data1D,(const uint16_t *)R1.Data1D,Size1D);
 	    return;
+    case 24: Conv24_1((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+	    return;
     case 32:Conv32_1((uint8_t *)Data1D,(const uint32_t *)R1.Data1D,Size1D);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
- #ifdef LO_ENDIAN
-    case 64:if(R1.Data1D)
-                Peel1BitNStep((uint8_t *)Data1D, 7+(const uint8_t*)R1.Data1D, Size1D, 0x807);
+#if defined(Conv64_1)
+    case 64:Conv64_1((uint8_t *)Data1D,(const uint64_t *)R1.Data1D,Size1D);
 	    return;
- #endif
- #ifdef HI_ENDIAN
-    case 64:Peel1BitNStep((uint8_t *)Data1D, (const uint8_t*)R1.Data1D, Size1D, 0x807);
-	    return;
- #endif
 #endif
     }
 
@@ -540,19 +537,19 @@ int i;
   }
   else
   {
-    uint8_t *N_Buffer8Bit = (uint8_t *)Data1D;
-    uint8_t Mask;
-    uint32_t Half = 1 << (i-1);
-    i = 0;
-    while(i<Size1D)
-    {    
-      *N_Buffer8Bit = 0;
-      for(Mask=0x80; Mask!=0; Mask>>=1)
+    uint8_t *N_Buffer8Bit = (uint8_t *)Data1D - 1;
+    const uint32_t Half = 1 << (i-1);
+    uint8_t Mask = 0;
+    for(unsigned x=0; x<Size1D; x++)
+    {
+      Mask >>= 1;
+      if(Mask == 0)
       {
-        if(R1.GetValue1D(i)>=Half) *N_Buffer8Bit |= Mask;
-        if(++i>=Size1D) return;
+        ++N_Buffer8Bit;
+        *N_Buffer8Bit = 0;
+        Mask = 0x80;
       }
-      N_Buffer8Bit++;
+      if(R1.GetValue1D(x)>=Half) *N_Buffer8Bit|=Mask;
     }
   }
 }
@@ -570,6 +567,8 @@ uint8_t Mask;
     {
     case 1: Raster1DAbstract::Get(R1);
 	    return;
+    case 2: Conv1_2((uint8_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
+	    return;
     case 4: Conv1_4((uint8_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
 	    return;
     case 8: Conv1_8((uint8_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
@@ -580,7 +579,7 @@ uint8_t Mask;
 	    return;
     case 32:Conv1_32((uint32_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
     case 64:Conv1_64((uint64_t*)R1.Data1D,(const uint8_t *)Data1D,Size1D);
             return;
 #endif
@@ -702,6 +701,40 @@ return 0;
 #endif
 
 
+#ifdef OPTIMISE_SPEED
+
+void Raster1D_2Bit::Get(Raster1DAbstract &R1) const
+{
+  switch(R1.GetPlanes())
+  {
+    case 1: Conv2_1((uint8_t*)R1.Data1D,(const uint8_t*)Data1D,Size1D);
+	    return;
+    case 8: Conv2_8((uint8_t*)R1.Data1D,(const uint8_t*)Data1D,Size1D);
+	    return;
+    case 16:Conv2_16((uint16_t*)R1.Data1D,(const uint8_t*)Data1D,Size1D);
+	    return;
+    case 24:Conv2_24((uint8_t*)R1.Data1D,(const uint8_t*)Data1D,Size1D);
+	    return;
+    case 32:Conv2_32((uint32_t*)R1.Data1D,(const uint8_t*)Data1D,Size1D);
+	    return;
+  }
+  Raster1DAbstract::Get(R1);
+}
+
+
+void Raster1D_2Bit::Set(const Raster1DAbstract &R1)
+{
+  switch(R1.GetPlanes())
+  {
+    case 1: Conv1_2((uint8_t*)Data1D,(const uint8_t*)R1.Data1D,Size1D);
+	    return;
+  }
+  Raster1DAbstract::Set(R1);
+}
+
+#endif
+
+
 /* ------------- 4 bit planes ------------- */
 
 void Raster1D_4Bit::SetValue1D(unsigned x, uint32_t NewValue)
@@ -764,8 +797,14 @@ void Raster1D_4Bit::Get(Raster1DAbstract &R1) const
 	    return;
     case 16:Conv4_16((uint16_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
 	    return;
+    case 24:Conv4_24((uint8_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
+	    return;
     case 32:Conv4_32((uint32_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
 	    return;
+#if defined(uint64_t_defined)
+    case 64:Conv4_64((uint64_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
+	    return;
+#endif
     }
 
   Raster1DAbstract::Get(R1);
@@ -784,6 +823,8 @@ void Raster1D_4Bit::Set(const Raster1DAbstract &R1)
 	    return;
     case 16:Conv16_4((uint8_t *)Data1D,(const uint16_t *)R1.Data1D,Size1D);
 	    return;
+    case 24: Conv24_4((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+	    return;
     case 32:Conv32_4((uint8_t *)Data1D,(const uint32_t *)R1.Data1D,Size1D);
 	    return;
     }
@@ -818,7 +859,7 @@ signed char shift;
 	    return;
     case 32:Conv8_32((uint32_t *)R1.Data1D,(const uint8_t*)Data1D,Size1D);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
     case 64:Conv8_64((uint64_t *)R1.Data1D,(const uint8_t*)Data1D,Size1D);
 	    return;
 #endif
@@ -854,6 +895,10 @@ unsigned i;
     {
     case 1: Conv1_8((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
     	    return;
+#ifdef OPTIMISE_SPEED
+    case 2: Conv2_8((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+    	    return;
+#endif
     case 4: Conv4_8((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
     	    return;
     case 8: Raster1DAbstract::Set(R1);
@@ -864,18 +909,10 @@ unsigned i;
             return;
     case 32:Conv32_8((uint8_t *)Data1D,(const uint32_t *)R1.Data1D,Size1D);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
- #ifdef LO_ENDIAN
-    case 64:if(R1.Data1D)
-                Peel8BitNStep((uint8_t *)Data1D, 7+(const uint8_t*)R1.Data1D, Size1D, 8);
+#if defined(uint64_t_defined) && defined(Conv64_8)
+    case 64:Conv64_8((uint8_t *)Data1D,(const uint64_t *)R1.Data1D,Size1D);
 	    return;
- #endif
- #ifdef HI_ENDIAN
-    case 64:Peel8BitNStep((uint8_t *)Data1D, (const uint8_t*)R1.Data1D, Size1D, 8);
-	    return;
- #endif
 #endif
-
     }
 
   uint8_t *N_Buffer8Bit = (uint8_t *)Data1D;
@@ -1043,7 +1080,7 @@ signed char shift;
 	    return;
     case 32:Conv16_32((uint32_t *)R1.Data1D,(const uint16_t *)Data1D,Size1D);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
     case 64:Conv16_64((uint64_t *)R1.Data1D,(const uint16_t *)Data1D,Size1D);
 	    return;
 #endif
@@ -1076,6 +1113,10 @@ signed char shift;
     {
     case 1: Conv1_16((uint16_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
     	    return;
+#ifdef OPTIMISE_SPEED
+    case 2: Conv2_16((uint16_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+    	    return;
+#endif
     case 4: Conv4_16((uint16_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
             return;
     case 8: Conv8_16((uint16_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
@@ -1086,7 +1127,7 @@ signed char shift;
             return;    
     case 32:Conv32_16((uint16_t *)Data1D,(const uint32_t *)R1.Data1D,Size1D);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
     case 64:Conv64_16((uint16_t *)Data1D,(const uint64_t *)R1.Data1D,Size1D);
 	    return;
 #endif
@@ -1249,13 +1290,17 @@ void Raster1D_24Bit::Get(Raster1DAbstract &R1) const
 {  
   switch(R1.GetPlanes())
     {
+    case 1: Conv24_1((uint8_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
+	    return;
+    case 4: Conv24_4((uint8_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
+	    return;
     case 8: Conv24_8((uint8_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
 	    return;
     case 16:Conv24_16((uint16_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
 	    return;
     case 32:Conv24_32((uint32_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
     case 64:Conv24_64((uint64_t *)R1.Data1D,(const uint8_t *)Data1D,Size1D);
 	    return;
 #endif
@@ -1270,13 +1315,17 @@ void Raster1D_24Bit::Set(const Raster1DAbstract &R1)
     {
     case 1: Conv1_24((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
 	    return;
+    case 2: Conv2_24((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+	    return;
+    case 4: Conv4_24((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+	    return;
     case 8: Conv8_24((uint8_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
 	    return;
     case 16:Conv16_24((uint8_t *)Data1D,(const uint16_t *)R1.Data1D,Size1D);
 	    return;
     case 32:Conv32_24((uint8_t *)Data1D,(const uint32_t *)R1.Data1D,Size1D);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
     case 64:Conv64_24((uint8_t *)Data1D,(const uint64_t *)R1.Data1D,Size1D);
 	    return;
 #endif
@@ -1404,11 +1453,10 @@ signed char shift;
 	    return;
     case 32:Raster1DAbstract::Get(R1);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
     case 64:Conv32_64((uint64_t *)R1.Data1D,(const uint32_t*)Data1D,Size1D);
 	    return;
 #endif
-
     }
 
   const uint32_t *N_Buffer32Bit = (const uint32_t *)Data1D;
@@ -1440,6 +1488,10 @@ signed char shift;
     {
     case 1: Conv1_32((uint32_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
     	    return;
+#ifdef OPTIMISE_SPEED
+    case 2: Conv2_32((uint32_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+    	    return;
+#endif
     case 4: Conv4_32((uint32_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
 	    return;
     case 8: Conv8_32((uint32_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
@@ -1450,7 +1502,7 @@ signed char shift;
 	    return;
     case 32:Raster1DAbstract::Set(R1);
 	    return;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
     case 64:Conv64_32((uint32_t *)Data1D,(const uint64_t *)R1.Data1D,Size1D);
 	    return;
 #endif
@@ -1552,7 +1604,7 @@ void Raster1D_32Bit::Join8Bit(const void *Buffer8Bit, uint8_t plane8)
 
 
 /* ------------ 64 bit planes -------------- */
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
 
 uint32_t Raster1D_64Bit::GetValue1D(unsigned x) const 
 {
@@ -1699,23 +1751,15 @@ void Raster1D_64Bit::Join8Bit(const void *Buffer8Bit, uint8_t plane8)
 void Raster1D_64Bit::Get(Raster1DAbstract &R1) const
 {
   switch(R1.GetPlanes())
-    {
-#ifdef LO_ENDIAN
-    case 1: if(Data1D)
-                Peel1BitNStep((uint8_t *)R1.Data1D, 7+(const uint8_t*)Data1D, Size1D, 0x807);
-	    return;
-    case 8: if(Data1D)
-                Peel8BitNStep((uint8_t *)R1.Data1D, 7+(const uint8_t*)Data1D, Size1D, 8);
+  {
+#ifdef Conv64_1
+    case 1: Conv64_1((uint8_t *)R1.Data1D,(const uint64_t *)Data1D,Size1D);
 	    return;
 #endif
-#ifdef HI_ENDIAN
-    case 1: Peel1BitNStep((uint8_t *)R1.Data1D, (const uint8_t*)Data1D, Size1D, 0x807);
-	    return;
-    case 8: Peel8BitNStep((uint8_t *)R1.Data1D, (const uint8_t*)Data1D, Size1D, 8);
+#ifdef Conv64_8
+    case 8: Conv64_8((uint8_t *)R1.Data1D,(const uint64_t *)Data1D,Size1D);
 	    return;
 #endif
-    //case 8: Conv64_8((uint8_t *)R1.Data1D,(const uint64_t *)Data1D,Size1D);
-    //	    return;
     case 16:Conv64_16((uint16_t *)R1.Data1D,(const uint64_t *)Data1D,Size1D);
 	    return;
     case 24:Conv64_24((uint8_t *)R1.Data1D,(const uint64_t *)Data1D,Size1D);
@@ -1733,6 +1777,8 @@ void Raster1D_64Bit::Set(const Raster1DAbstract &R1)
     {
     case 1: Conv1_64((uint64_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
 	    return;
+    case 4: Conv4_64((uint64_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
+	    return;
     case 8: Conv8_64((uint64_t *)Data1D,(const uint8_t *)R1.Data1D,Size1D);
 	    return;
     case 16:Conv16_64((uint64_t *)Data1D,(const uint16_t *)R1.Data1D,Size1D);
@@ -1814,7 +1860,6 @@ void Raster1D_32FltBit::Get(Raster1DAbstract &R1) const
 {
 const float *N_BufferFlt = (float *)Data1D;
 int i;
-float MaxVal;
 
   i = R1.GetPlanes();
   
@@ -1830,7 +1875,7 @@ float MaxVal;
     }
   else
     {
-    MaxVal = (1<<i) - 1;
+    const float MaxVal = (1<<i) - 1;
 
     for(i=0;i<Size1D;i++)
       {
@@ -1851,7 +1896,6 @@ void Raster1D_32FltBit::Set(const Raster1DAbstract &R1)
 {
 float *N_BufferFlt = (float *)Data1D;
 int i;
-float MaxVal;
 
   i = R1.GetPlanes();
   
@@ -1867,7 +1911,7 @@ float MaxVal;
     }
   else
     {
-    MaxVal = (1<<i) - 1;
+    const float MaxVal = (1<<i) - 1;
     for(i=0; i<Size1D; i++)
       {
       *N_BufferFlt++ = R1.GetValue1D(i) * MaxVal;
@@ -1945,10 +1989,8 @@ void Raster1D_64FltBit::PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double New
 void Raster1D_64FltBit::Get(Raster1DAbstract &R1) const
 {
 const double *N_BufferFlt = (const double *)Data1D;
-int i;
-float MaxVal;
 
-  i = R1.GetPlanes();
+  const int i = R1.GetPlanes();
   
   if(i<0)		// Float or double.
     {
@@ -1956,22 +1998,22 @@ float MaxVal;
       memcpy(R1.Data1D, Data1D, Size1D*sizeof(float));
     else
       {
-      for(i=0; i<Size1D; i++)
-        R1.SetValue1Dd(i, *N_BufferFlt++);
+      for(unsigned x=0; x<Size1D; x++)
+        R1.SetValue1Dd(x, *N_BufferFlt++);
       }
     }
   else
     {
-    MaxVal = (1<<i) - 1;
+    const float MaxVal = (1<<i) - 1;
 
-    for(i=0;i<Size1D;i++)
+    for(unsigned x=0; x<Size1D; x++)
       {
       if(*N_BufferFlt>1)
-        R1.SetValue1D(i,MaxVal);
+        R1.SetValue1D(x,MaxVal);
       else if(*N_BufferFlt<0)
-        R1.SetValue1D(i,0);
+        R1.SetValue1D(x,0);
       else
-        R1.SetValue1D(i,*N_BufferFlt*MaxVal);
+        R1.SetValue1D(x,*N_BufferFlt*MaxVal);
 
       N_BufferFlt++;
       }
@@ -1982,10 +2024,8 @@ float MaxVal;
 void Raster1D_64FltBit::Set(const Raster1DAbstract &R1)
 {
 double *N_BufferFlt = (double *)Data1D;
-int i;
-double MaxVal;
 
-  i = R1.GetPlanes();
+  const int i = R1.GetPlanes();
   
   if(i<0)		// Float or double.
     {
@@ -1993,16 +2033,16 @@ double MaxVal;
       memcpy(Data1D, R1.Data1D, Size1D*sizeof(float));
     else
       {
-      for(i=0; i<Size1D; i++)
-        *N_BufferFlt++ = R1.GetValue1Dd(i);
+      for(unsigned x=0; x<Size1D; x++)
+        *N_BufferFlt++ = R1.GetValue1Dd(x);
       }
     }
   else
     {
-    MaxVal = (1<<i) - 1;
-    for(i=0;i<Size1D;i++)
+    const double MaxVal = (1<<i) - 1;
+    for(unsigned x=0; x<Size1D; x++)
       {
-      *N_BufferFlt++ = R1.GetValue1D(i) * MaxVal;
+      *N_BufferFlt++ = R1.GetValue1D(x) * MaxVal;
       }
     }
 }
@@ -2030,7 +2070,7 @@ switch(Planes)
    case 16: Raster=new Raster1D_16Bit;  break;
    case 24: Raster=new Raster1D_24Bit;  break;
    case 32: Raster=new Raster1D_32Bit;  break;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
    case 64: Raster=new Raster1D_64Bit;  break;
 #endif
    default:return(NULL);
@@ -2452,6 +2492,17 @@ void Raster1D_8BitRGB::Set(const Raster1DAbstract &R1)
  Raster1DAbstractRGB::Set(R1);
 }
 
+#ifdef OPTIMISE_SPEED
+void  Raster1D_8BitRGB::Set(unsigned x, const RGBQuad *RGB)
+{
+  if(Size1D<=x || RGB==NULL) return;
+  x *= 3;
+  ((uint8_t *)Data1D)[x] = RGB->R & 0xFF;
+  ((uint8_t *)Data1D)[x+1] = RGB->G & 0xFF;
+  ((uint8_t *)Data1D)[x+2] = RGB->B & 0xFF;
+}
+#endif
+
 
 #ifdef _REENTRANT
 
@@ -2873,31 +2924,30 @@ return(Raster);
 
 void Raster2DAbstract::Erase2DStub(void)
 {
-unsigned SaveSize1D;
-
+ //printf("Erasing Ras2D |%p|",Data2D);
  if(Shadow)
-   {
-   Data2D=NULL;
-   Size2D=0;
+ {
+   Data2D = NULL;
+   Size2D = 0;
    Erase1DStub();
    return;
-   }
+ }
 
  if(Data2D)
-   {
-   SaveSize1D = Size1D;
+ {
+   const unsigned SaveSize1D = Size1D;
    for(unsigned i=0; i<Size2D; i++)
 	{
-	Size1D=SaveSize1D;
-	Data1D=Data2D[i];
+	Size1D = SaveSize1D;
+	Data1D = Data2D[i];
 	Raster1DAbstract::Erase1D();
 	}
    free(Data2D);
    Data2D = NULL;
-   }
+ }
  else
    Raster1DAbstract::Erase1D();
-Size2D=0;
+ Size2D = 0;
 }
 
 
@@ -2946,6 +2996,7 @@ unsigned i;
      return;
      }
    }
+ //printf("Allocate2D |%p|",Data2D);
 }
 
 
@@ -2983,7 +3034,7 @@ void Raster2DAbstract::Set(unsigned Offset1D, unsigned Offset2D, const RGBQuad *
 {
   if(Data2D==NULL || Offset2D>=Size2D) return;
   Data1D = Data2D[Offset2D];
-  ((Raster1DAbstract*)this)->Set(Offset1D,RGB);		//Raster1DAbstract::Get() forces only one method not using VMT.
+  ((Raster1DAbstract*)this)->Set(Offset1D,RGB);		//Raster1DAbstract::Set() forces only one method not using VMT.
 }
 
 
@@ -3156,7 +3207,7 @@ switch(Planes)
    case 16:Raster=new Raster2D_16Bit;  break;
    case 24:Raster=new Raster2D_24Bit;  break;
    case 32:Raster=new Raster2D_32Bit;  break;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
    case 64:Raster=new Raster2D_64Bit;  break;
 #endif
    default:return(NULL);
@@ -3173,6 +3224,7 @@ if(Raster)
 	}
      }
    }
+   //printf("CreateRaster2D |%p|",Raster->Data2D);
 
 return(Raster);
 }
@@ -3427,7 +3479,7 @@ switch(Planes)
    case 16:Raster=new Raster3D_16Bit;  break;
    case 24:Raster=new Raster3D_24Bit;  break;
    case 32:Raster=new Raster3D_32Bit;  break;
-#if defined(uint64_t) || defined(uint64_t_defined)
+#if defined(uint64_t_defined)
    case 64:Raster=new Raster3D_64Bit;  break;
 #endif
    default:return(NULL);
