@@ -15,7 +15,7 @@
 
 
 #if !defined(__DJGPP__)
-#include "../jobs/csext.h"
+#include "../atoms/include/csext.h"
 #endif
 
 #if defined(__DJGPP__) || defined(_WIN32)
@@ -299,7 +299,7 @@ unsigned TablePosStart;
 
  F = fopen(Switch,"wb");
  fprintf(F,
-    "/*Do not edit this file. It is automatically generated.*/\n"
+    "/*Do not edit this file. It is automatically generated in %s.*/\n"
     "\n"
     "#ifdef __Limited_Proc_Size\n"
     " char *BorlandCPPIsShit(uint16_t wchar, TconvertedPass1 *cq);\n"
@@ -348,7 +348,7 @@ unsigned TablePosStart;
     "	}\n"
     "\n"
     "switch(wchar_code) {\n"
-    "\n", TablePosStart, TablePosStart, j);
+    "\n", __DATE__, TablePosStart, TablePosStart, j);
 
  Fcp = fopen(Table,"wb");
  j = 0;
@@ -521,9 +521,10 @@ int main(int argc, char *argv[])
 {
 FILE *F;
 codepage internal;
-codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1276, cpkam,
+codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1256, cp1276, cpkam,
          cpwp4a, cpwp5, cpwp5_cz, cpwp6,
-	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4, iso_8859_5,
+	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4, iso_8859_5, iso_8859_6, iso_8859_7,
+         iso_8859_8,
          unicode,koi8cs,koi8r,
 	 mtef2,
          MAC_ROMAN;
@@ -534,7 +535,7 @@ doublelist llHTML;
 string FileName;
 int TimeoutCounter;
 
- puts("<<<cplib>>> (c)1999-2023 J.Fojtik");
+ puts("<<<cplib>>> (c)1999-2025 J.Fojtik");
 
  if(argc>1)
    {
@@ -611,9 +612,10 @@ int TimeoutCounter;
  if(!LoadCodePage("cp1253",cp1253,0)) return -7;
  LoadCodePage("cp1254",cp1254,0);
  if(!LoadCodePage("cp1255",cp1255,0)) return -8;
- if(!LoadCodePage("cp1276",cp1276,0)) return -9;
+ if(!LoadCodePage("cp1256",cp1256,0)) return -9;
+ if(!LoadCodePage("cp1276",cp1276,0)) return -10;
 
- if(!LoadCodePage("kam",cpkam,0)) return -10;
+ if(!LoadCodePage("kam",cpkam,0)) return -11;
  LoadCodePage("koi8cs",koi8cs,0);
  LoadCodePage("koi8_r",koi8r,0);
 
@@ -627,6 +629,12 @@ int TimeoutCounter;
  if(iso_8859_4.name) {free(iso_8859_4.name);iso_8859_4.name=strdup("iso_8859_4");}
  LoadCodePage("is8859_5",iso_8859_5,0);
  if(iso_8859_5.name) {free(iso_8859_5.name);iso_8859_5.name=strdup("iso_8859_5");}
+ LoadCodePage("is8859_6",iso_8859_6,0);
+ if(iso_8859_6.name) {free(iso_8859_6.name);iso_8859_6.name=strdup("iso_8859_6");}
+ LoadCodePage("is8859_7",iso_8859_7,0);
+ if(iso_8859_7.name) {free(iso_8859_7.name);iso_8859_7.name=strdup("iso_8859_7");}
+ LoadCodePage("is8859_8",iso_8859_8,0);
+ if(iso_8859_8.name) {free(iso_8859_8.name);iso_8859_8.name=strdup("iso_8859_8");}
 
 
  //if(heapcheck()<=0)
@@ -679,7 +687,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
    printf("Cannot write to the file \"%s\"", FileName());
    return -3;
  }
- fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ fprintf(F,"/*Do not edit this file. It is automatically generated in %s.*/\n", __DATE__);
  BuildTranslator(cphtml,internal,F);
  WriteStringTable(F,cphtml,llHTML);
  cphtml.Erase();
@@ -692,14 +700,18 @@ WriteTranslator(cp1250,cpkam,trn,F);
    printf("Cannot write to the file \"%s\"", FileName());
    return -2;
  }
- fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ fprintf(F,"/*Do not edit this file. It is automatically generated in %s.*/\n", __DATE__);
  BuildTranslator(cpkam,internal,F);		cpkam.Erase();
+ fprintf(F,"WCpTranslator cp895internal(\"cp895TOinternal\",255,kam_internal);\n\n");	// alias
 
  BuildTranslator(iso_8859_1,internal,F);	iso_8859_1.Erase();
  BuildTranslator(iso_8859_2,internal,F);	iso_8859_2.Erase();
  BuildTranslator(iso_8859_3,internal,F);	iso_8859_3.Erase();
  BuildTranslator(iso_8859_4,internal,F);	iso_8859_4.Erase();
  BuildTranslator(iso_8859_5,internal,F);	iso_8859_5.Erase();
+ BuildTranslator(iso_8859_6,internal,F);	iso_8859_6.Erase();
+ BuildTranslator(iso_8859_7,internal,F);	iso_8859_7.Erase();
+ BuildTranslator(iso_8859_8,internal,F);	iso_8859_8.Erase();
 
  BuildTranslator(cp852,internal,F);		cp852.Erase();
  BuildTranslator(cp1250,internal,F);		cp1250.Erase();
@@ -708,12 +720,14 @@ WriteTranslator(cp1250,cpkam,trn,F);
  BuildTranslator(cp1253,internal,F);		cp1253.Erase();
  BuildTranslator(cp1254,internal,F);		cp1254.Erase();
  BuildTranslator(cp1255,internal,F);		cp1255.Erase();
+ BuildTranslator(cp1256,internal,F);		cp1256.Erase();
  BuildTranslator(cp1276,internal,F);		// no erase, will be needed
  BuildTranslator(koi8cs,internal,F);		koi8cs.Erase();
  BuildTranslator(koi8r,internal,F);		koi8r.Erase();
  BuildTranslator(unicode,internal,F);		// no erase, will be needed
 
 	// *************** Output codepage generator *****************
+ for(int i=128;i<=159;i++) unicode.InsertCharDesc(i,"Control Code",false);
  BuildTranslator(internal,unicode, F);		unicode.Erase();
  BuildTranslator(internal,cp1276, F);		cp1276.Erase();
  BuildTranslator(internal,symbol, F);		// no erase, will be needed
@@ -741,7 +755,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
    goto SkipMtef;
  }
 
- fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ fprintf(F,"/*Do not edit this file. It is automatically generated in %s.*/\n", __DATE__);
  BuildTranslator(symbol, internal, F);		symbol.Erase();
  BuildTranslator(Wingdings, internal, F);	Wingdings.Erase();
  BuildTranslator(mtef2, internal, F);		mtef2.Erase();
@@ -756,7 +770,7 @@ SkipMtef:
    printf("Cannot write to the file \"%s\"", FileName());
    return -3;
  }
- fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ fprintf(F,"/*Do not edit this file. It is automatically generated in %s.*/\n", __DATE__);
  BuildTranslator(MAC_ROMAN,internal,F);		MAC_ROMAN.Erase();
  if(FcloseEpilog(F,FileName(),"macroman.trn")) return -1;
 
