@@ -202,9 +202,10 @@ unsigned i;
  
  switch(Attr)
  {
-   case Cyr_Font: Cyrillic = true; break;
-   case Heb_Font: cjHebrew = true; break;
-   case Georgia_Font: mxedruli = true; break;
+   case Cyr_Font: Cyrillic=true; break;
+   case Heb_Font: cjHebrew=true; break;
+   case Georgia_Font: mxedruli=true; break;
+   case Arabic_Font: arabtex=true; break;
  }
 
 return;
@@ -231,7 +232,7 @@ return(-1);
    It must generate some output to string.   */
 void _AttrOff(attribute & a, char Attr, string & s)
 {
-int pos;
+unsigned pos;
 
  s.erase();
 
@@ -279,17 +280,21 @@ string s;
  if(!s.isEmpty()) fputs(s(),cq->strip);
 
  if(attr_num==Heb_Font && cq->Font==FONT_HEBREW)
-   {
+ {
    cq->Font = FONT_NORMAL;
-   }
+ }
  if(attr_num==Cyr_Font && cq->Font==FONT_CYRILLIC)
-   {
+ {
    cq->Font = FONT_NORMAL;
-   }
+ }
  if(attr_num==Georgia_Font && cq->Font==FONT_GEORGIA)
-   {
+ {
    cq->Font = FONT_NORMAL;
-   }
+ }
+ if(attr_num==Arabic_Font && cq->Font==FONT_ARABIC)
+ {
+   cq->Font = FONT_NORMAL;
+ }
 
 return;
 }
@@ -363,7 +368,7 @@ RejectAttr:
 /** This procedure creates opening&closing sequence of attrs after that Base will have same items as A_new. */
 void AttrFit(attribute & Base, const attribute & A_New, string & s)
 {
-int i,pos;
+unsigned pos, i;
 const char *ch;
 
  s.erase();
@@ -726,15 +731,14 @@ void Make_tableentry_tabset(TconvertedPass1 *cq)
   fprintf(cq->log,"\n#Make_tableentry_tabset() ");fflush(cq->log);
 #endif
   unsigned char b = 'S';
-  long j, FORLIM;
 
   fwrite(&b, sizeof(unsigned char), 1, cq->table);
 
   b = cq->num_of_tabs;
   fwrite(&b, sizeof(unsigned char), 1, cq->table);
 
-  FORLIM = cq->num_of_tabs;
-  for(j=0; j<FORLIM; j++)
+  const int FORLIM = cq->num_of_tabs;
+  for(int j=0; j<FORLIM; j++)
     Wr_word(cq->table, cq->tabpos[j]);
 }
 
@@ -911,9 +915,17 @@ void CharacterStr(TconvertedPass1 *cq, const char *LatexCode)
                  {
 		 AttrOff(cq,Georgia_Font);
                  }
+               if(cq->Font==FONT_ARABIC)
+                 {
+		 AttrOff(cq,Arabic_Font);
+                 }
 	       cq->Font = FONT_NORMAL;
 	       fprintf(cq->strip, "\\rm ");
 	       break;
+         case FONT_ARABIC:
+	       AttrOn(cq->attr,Arabic_Font);
+	       cq->Font = FONT_ARABIC;
+	       break;
 	 case FONT_CYRILLIC:		//cyrillic font
 	       AttrOn(cq->attr,Cyr_Font);
 	       cq->Font = FONT_CYRILLIC;
@@ -1032,6 +1044,7 @@ uint8_t Red,Green,Blue;
   if(Red==0xFF && Green==0 && Blue==0xFF) ColorType="magenta";
   if(Red==0 && Green==0xFF && Blue==0xFF) ColorType="cyan";
 
+  Close_All_Attr(cq->attr,cq->strip);		// I am not sure here whether to close all attrs.
   if(*ColorType!='?')
 	fprintf(cq->strip, "\\color{%s}",ColorType);
   else fprintf(cq->strip, "\\color[rgb]{%1.2f,%1.2f,%1.2f}",
@@ -1586,7 +1599,6 @@ void ParagraphNumber(TconvertedPass1 *cq)
   fprintf(cq->log,"\n#ParagraphNumber() ");fflush(cq->log);
 #endif
   unsigned char ParNumType;
-  int i;
   static char count='A';
 
 
@@ -1596,17 +1608,17 @@ void ParagraphNumber(TconvertedPass1 *cq)
 		  else sprintf(cq->ObjType, "ParNum:%d",(int)ParNumType);
 
 /* check whether the section is opened */
-  for(i = 0; i < cq->attr.Closed_Depth; i++)
-	{
-	if(cq->attr.stack[i] >= First_com_section &&
-	   cq->attr.stack[i] <= Last_com_section) return;
-	}
+  for(unsigned i=0; i<cq->attr.Closed_Depth; i++)
+  {
+    if(cq->attr.stack[i] >= First_com_section &&
+	cq->attr.stack[i] <= Last_com_section) return;
+  }
 
 
   if (cq->attr.Closed_Depth!=cq->attr.Opened_Depth)
-	 {
+  {
 	 Open_All_Attr(cq->attr,cq->strip);
-	 }
+  }
   if(ParNumType>=0x80) {
 		       ParNumType=0x80;	//!!!!!!!!!!! opravit !!!!!
 		       fprintf(cq->strip, "\\label{ParNum_%c}\\ref{ParNum_%c}",count,count );
@@ -1870,14 +1882,14 @@ void SetFont(TconvertedPass1 *cq, int PointSize, const char *FontName)
 #ifdef DEBUG
   fprintf(cq->log,"\n#SetFont(%d,%s) ",PointSize,chk(FontName));fflush(cq->log);
 #endif
-int i;
+unsigned i;
 string TexFontName(FontName);
 const char *FontTblItem;
 
  if(FontName!=NULL)
    {
    TexFontName="WP:"+TexFontName;
-   for(i=0;i<length(FontTable);i++)	//Try to find LaTeX equivalent of WP font
+   for(i=0; i<length(FontTable); i++)	//Try to find LaTeX equivalent of WP font
 	{
 	if((FontTblItem=FontTable[i]) == NULL) continue;
 	if(strstr(FontTblItem,TexFontName())!=NULL)
@@ -2063,7 +2075,6 @@ void StartSection(TconvertedPass1 *cq, signed char WP)
   fprintf(cq->log,"\n#StartSection() ");fflush(cq->log);
 #endif
   unsigned char b;
-  int i;
 
   if(WP>0)
       {
@@ -2075,28 +2086,27 @@ void StartSection(TconvertedPass1 *cq, signed char WP)
   sprintf(cq->ObjType, "Start MarkToC %d",(int)b);
 
 			/* check whether any section is already opened */
-  for (i = 0; i < cq->attr.Closed_Depth; i++)
-	{
-	if(cq->attr.stack[i] >= First_com_section &&
-	   cq->attr.stack[i] <= Last_com_section)
-	     {
-	     if (cq->err != NULL)
-	       {
-	       cq->perc.Hide();
-	       fprintf(cq->err, _("\nWarning: Double MarkToC %d inside %d, second one will be ignored!"),
-                       (int)b, (int)(cq->attr.stack[i]-First_com_section));
-	       }
-	     return;
-	     }
-	}
-
+  for(unsigned i=0; i<cq->attr.Closed_Depth; i++)
+  {
+    if(cq->attr.stack[i] >= First_com_section &&
+    cq->attr.stack[i] <= Last_com_section)
+    {
+      if (cq->err != NULL)
+      {
+         cq->perc.Hide();
+	 fprintf(cq->err, _("\nWarning: Double MarkToC %d inside %d, second one will be ignored!"),
+                 (int)b, (int)(cq->attr.stack[i]-First_com_section));
+      }
+      return;
+    }
+  }
 
   if (cq->FirstSection > 100)
-	{			   /*setup for 1'st section in the document*/
-	cq->FirstSection = 0;
-	if (b == 1) cq->FirstSection = 1;
-	}
-  if (b > 0) b -= cq->FirstSection;
+  {			   /*setup for 1'st section in the document*/
+    cq->FirstSection = 0;
+    if(b == 1) cq->FirstSection = 1;
+  }
+  if(b > 0) b -= cq->FirstSection;
 
   b += OutputStyle;
   if (b > Last_com_section) return;
@@ -2185,7 +2195,7 @@ void Tab(TconvertedPass1 *cq, char WP)
 #endif
 int j;
 uint16_t wpu;
-int tabnum, new_tabs, FORLIM;
+int tabnum, new_tabs;
 const char *TabType="";
 
   if (cq->envir != 'I' && cq->envir != 'i' && cq->envir != 'B' && !cq->nomore_valid_tabs
@@ -2245,15 +2255,15 @@ const char *TabType="";
      else wpu -= cq->WP_sidemargin;  /* Correctie ivm WP kantlijn */
 
     tabnum = 0;
-    FORLIM = cq->num_of_tabs;
-    for (j = 1; j <= FORLIM; j++)
+    const int FORLIM = cq->num_of_tabs;
+    for (j=1; j<=FORLIM; j++)
       {   /* Bepaal welke tabpos */
       if (wpu >= cq->tabpos[j-1]) tabnum = j;
       }
 
     new_tabs = tabnum - cq->latex_tabpos;
 
-    for(j=0;j<cq->attr.Closed_Depth;j++)
+    for(j=0; j<cq->attr.Closed_Depth; j++)
     	{
 	if(cq->attr.stack[j]>=0x10 && cq->attr.stack[j]<=0x13)
         	{		/* \section{ attribute found */
@@ -2369,7 +2379,7 @@ void Terminate_Line(TconvertedPass1 *cq, char line_term)
 	}
   
   if(line_term=='h' || line_term=='P')
-    for(int j=0; j<cq->attr.Opened_Depth; j++)		// Look for subscript and superscript.
+    for(unsigned j=0; j<cq->attr.Opened_Depth; j++)		// Look for subscript and superscript.
       {
       if(cq->attr.stack[j]==5 || cq->attr.stack[j]==6)	// subscript or superscript
         {
