@@ -40,6 +40,7 @@
 extern list HTMLChars;
 int SavePictureEPS(const char *Name, const Image &Img);
 void CheckOversizedImage(Image *PImg);
+float NormAngleDEG(float num1);
 
 
 /** Functor class for SVG transform. */
@@ -189,6 +190,17 @@ bool ReadFloat(const char **pstr, float &f)
     str++;
     while(isdigit(*str)) str++;
   }
+  if(*str=='e')
+  {
+    str++;
+    if(*str=='-' || *str=='+') str++;
+    while(isdigit(*str)) str++;
+    if(*str=='.')		// Only one dot is tolerated inside exponent.
+    {
+      str++;
+      while(isdigit(*str)) str++;
+    }
+  }
 
   while(isspace(*str)) str++;
 
@@ -233,10 +245,16 @@ typedef enum
 } E_SVG_TAGS;
 
 
-/*Register translator object here*/
+/// Register translator object here.
 class TconvertedPass1_SVG: virtual public TconvertedPass1_XML, virtual public TconvertedPass1_Image
      {
 protected:
+     typedef struct
+     {
+       float rx, ry, rotation, dx, dy;
+       char large_arc, sweep;
+     } SvgEllipse;
+
      VectorList VectList;			///< Main Vector object list.
      doublelist StyleDict;
      PS_State PSS;
@@ -265,6 +283,8 @@ protected:
      void ClosePathLine(float **pPoints, int & n, bool Close=false, AbstractTransformXY *Tx=NULL);
      void ClosePathCurve(float **pPoints, int & n, bool Close=false, AbstractTransformXY *Tx=NULL);
      void SolveExtProperty(const char *PropName, vecPen *pVvecPen, vecBrush *pVvecBrush);
+     bool SolveEllipse(const SvgEllipse &Ellip, double x1, double y1, double x2, double y2, AbstractTransformXY *Tx);
+     bool FakeEllipse(float x2, float y2, AbstractTransformXY *Tx, char CharPassed);
 
 public:
      TconvertedPass1_SVG(void);
@@ -312,7 +332,8 @@ ImplementReader(SVG,".SVG")
    LoadPictureSVG,
    NULL);
 
-#define SVGVersion "0.13"
+
+#define SVGVersion "0.17"
 
 
 TconvertedPass1_SVG::TconvertedPass1_SVG(void): DelayedObjects(NULL), objs(NULL) 
@@ -1064,7 +1085,7 @@ const float FontSizeBk = PSS.FontSize;
   while(!feof(wpd))
   {
     ReadXMLTag(false);
-    if(by==XML_closetag && TAG=="</a>")
+    if((by==XML_closetag||by==XML_closedclosetag) && TAG=="</a>")
         break;
     ProcessKeySVG();
   }
@@ -1137,7 +1158,7 @@ const float FontSizeBk = PSS.FontSize;
   while(!feof(wpd))
   {
     ReadXMLTag(false);
-    if(by==XML_closetag && TAG=="</g>")
+    if((by==XML_closetag||by==XML_closedclosetag) && TAG=="</g>")
         break;
     ProcessKeySVG();
   }
@@ -1192,7 +1213,7 @@ string key, commands;
   while(!feof(wpd))
   {
     ReadXMLTag(false);
-    if(by==XML_closetag && TAG=="</style>")
+    if((by==XML_closetag||by==XML_closedclosetag) && TAG=="</style>")
         break;
     if(by==XML_char)
     {
@@ -1315,7 +1336,7 @@ bool SpaceAdded = false;
   while(!feof(wpd))
   {
     ReadXMLTag(false);
-    if(by==XML_closetag && TAG=="</text>")
+    if((by==XML_closetag||by==XML_closedclosetag) && TAG=="</text>")
         break;
 
     if(by==XML_tag && TAG=="<tspan>")
@@ -1362,7 +1383,7 @@ bool SpaceAdded = false;
       while(!feof(wpd))
       {
         ReadXMLTag(false);
-        if(by==XML_closetag && TAG=="</tspan>")
+        if((by==XML_closetag||by==XML_closedclosetag) && TAG=="</tspan>")
             break;
         switch(by)
         {
@@ -1585,11 +1606,12 @@ float stroke_width;
       Tx->ApplyTransform((*pPoints)[6*i+2], (*pPoints)[6*i+3]);
       Tx->ApplyTransform((*pPoints)[6*i+4], (*pPoints)[6*i+5]);
     }
-    UpdateBBox(bbx,0, (*pPoints)[6*i], (*pPoints)[6*i+1], 0, 0);
+    UpdateBBox(bbx,0, (*pPoints)[6*i],   (*pPoints)[6*i+1], 0, 0);	// start point    
   }
   PositionX = (*pPoints)[6*n];
   PositionY = (*pPoints)[6*n+1];
   if(Tx) Tx->ApplyTransform((*pPoints)[6*n], (*pPoints)[6*n+1]);	// The last curve point must be also transformed.
+  UpdateBBox(bbx,0, (*pPoints)[6*n], (*pPoints)[6*n+1], 0, 0);		// curve end point
 
   VectorCurve *pVecCurve = new VectorCurve(*pPoints, 3*n+1); n=0;
   *pPoints = NULL;
@@ -1624,7 +1646,6 @@ void TconvertedPass1_SVG::ImageEmbed(void)
   fprintf(log,"\n#ImageEmbed() ");fflush(log);
 #endif
 int i;
-const char *FileName=NULL;
 string NewFileName;
 float x, y, Width, Height;
 
@@ -1641,7 +1662,7 @@ float x, y, Width, Height;
 
   if((i=TAG_Args IN "src")>=0 || (i=TAG_Args IN "SRC")>=0)
   {
-    FileName = TAG_Args.Member(i,1);
+    const char *FileName = TAG_Args.Member(i,1);
     if(FileName!=NULL)
     {
       for(i=0; i<sizeof(MimeList)/sizeof(TMimeItem); i++)
@@ -1670,12 +1691,12 @@ float x, y, Width, Height;
             fprintf(err,_("\nError: Cannot create image file: \"%s\"."),NewFileName());
           }
         }
-      FileName = NewFileName();
+        //FileName = NewFileName();
       }
     }
   }
 
-  if((i=TAG_Args IN "xlink:href") > 0)
+  if((i=TAG_Args IN "xlink:href") >= 0)
   {
     char *Mime = TAG_Args.Member(i,1);
     char *Contents = Mime;
@@ -1692,7 +1713,7 @@ float x, y, Width, Height;
           if(!strncmp(Mime,MimeList[i].MimeType,MimeList[i].TypeLen))
           {
             NewFileName = MergePaths(OutputDir,RelativeFigDir) + GetSomeImgName(MimeList[i].ImageExt);
-            FileName += MimeList[i].TypeLen + 1;
+            //FileName += MimeList[i].TypeLen + 1;
             break;
           }
         }
@@ -1716,7 +1737,7 @@ float x, y, Width, Height;
         {
           base64_decode(Contents, F);
           fclose(F);
-          FileName = NewFileName();
+          //FileName = NewFileName();
         }
         else
         {
@@ -1730,16 +1751,46 @@ float x, y, Width, Height;
     }
   }
 
-  Image Img2(LoadPicture(NewFileName()));
-  if(!Img2.isEmpty())
+  if((i=TAG_Args IN "href") >= 0)
   {
-    if(Img2.Raster!=NULL)
+    const char *Contents = TAG_Args.Member(i,1);
+    if(Contents!=NULL && !strncmp(Contents,"data:",5))
     {
-       VectorRaster *VecR = new VectorRaster(y, y+Height, x+Width, x);
-       VecR->AttachRaster(Img2.Raster);
-       VecR->AttachPalette(Img2.Palette);
-       VecR->CalcBoundingBox(bbx);
-       VectList.AddObject(VecR);
+      for(i=0; i<sizeof(MimeList)/sizeof(TMimeItem); i++)
+      {
+        if(!strncmp(Contents,MimeList[i].MimeType,MimeList[i].TypeLen))
+        {
+          Contents += MimeList[i].TypeLen;
+          if(*Contents==',') Contents++;
+          NewFileName = MergePaths(OutputDir,RelativeFigDir) + GetSomeImgName(MimeList[i].ImageExt);
+          FILE *F=fopen(NewFileName(),"wb");
+          if(F==NULL) {NewFileName.erase();break;}
+          base64_decode(Contents, F);
+          fclose(F);
+          break;
+        }
+      }
+    }
+  }
+
+  if(!NewFileName.isEmpty())
+  {
+    Image Img2(LoadPicture(NewFileName()));
+    if(!Img2.isEmpty() && Img2.Raster!=NULL)
+    {
+      VectorRaster *VecR = new VectorRaster(y, y+Height, x+Width, x);
+      VecR->AttachRaster(Img2.Raster);
+      VecR->AttachPalette(Img2.Palette);
+      VecR->CalcBoundingBox(bbx);
+      VectList.AddObject(VecR);
+    }
+    else
+    {
+      if(err != NULL)
+      {
+        perc.Hide();
+        fprintf(err,_("\nError: Cannot load image file: \"%s\"."),NewFileName());
+      }
     }
   }
 
@@ -1800,6 +1851,109 @@ void TconvertedPass1_SVG::SolveExtProperty(const char *PropName, vecPen *pVvecPe
 }
 
 
+/// https://www.w3.org/TR/SVG/implnote.html#ArcConversionEndpointToCenter
+/// param[in]	Ellip	Shape and parametters of ellipsis.
+/// param[in]	x1	Ellipse start point x coordinate.
+/// param[in]	y1	Ellipse start point y coordinate.
+bool TconvertedPass1_SVG::SolveEllipse(const SvgEllipse &Ellip, double x1, double y1, double x2, double y2, AbstractTransformXY *Tx)
+{
+const double a2 = Ellip.rx * Ellip.rx;
+const double b2 = Ellip.ry * Ellip.ry;
+const double cos_fi = cos(M_PI*Ellip.rotation/180);
+const double sin_fi = sin(M_PI*Ellip.rotation/180);
+const double xMid = (x1-x2) / 2;
+const double yMid = (y1-y2) / 2;
+
+  if(fabs(xMid)<1e-3 && fabs(yMid)<1e-3)	// Zero size arc - ignorred.
+  {
+    return true;
+  }
+
+  if(fabs(Ellip.rx)<1e-3 || fabs(Ellip.ry)<1e-3) return false;
+
+	// Step 1: Compute (x1', y1')
+  const double x1c =  cos_fi*xMid + sin_fi*yMid;
+  const double y1c = -sin_fi*xMid + cos_fi*yMid;
+
+	// Step 2: Compute (cx', cy')
+  double d = (a2*b2 - a2*y1c*y1c - b2*x1c*x1c) / (a2*y1c*y1c + b2*x1c*x1c);
+  if(d<0) return false;
+  d = sqrt(d);
+  if(Ellip.sweep==Ellip.large_arc) d=-d;
+
+  const double cxc =  d * y1c * Ellip.rx/Ellip.ry; 
+  const double cyc = -d * x1c * Ellip.ry/Ellip.rx;
+
+	// Step 3: Compute (cx, cy) from (cx', cy')
+  const double cx = cos_fi*cxc - sin_fi*cyc + (x1+x2)/2;
+  const double cy = sin_fi*cxc + cos_fi*cyc + (y1+y2)/2;
+
+	// Step 4
+  const float fi1 = atan2(y1-cy, x1-cx);
+  const float fi2 = atan2(y2-cy, x2-cx);
+
+  float fi = fi1;
+  int i = 0;
+  while(fabs(NormAngleDEG(180*(fi-fi2)/M_PI)) > 11)
+  {
+    i++;
+    if(Ellip.sweep)
+      fi += 10*M_PI/180;
+    else
+      fi -= 10*M_PI/180;
+  }
+  if(i==0) return false;
+  
+  float *Points = (float*)malloc(2*(i+1)*sizeof(float));
+  if(!Points) return false;
+
+  Points[0]=x1;		Points[1]=y1;
+  fi = fi1 - M_PI*Ellip.rotation/180;
+  for(int j=1; j<i; j++)
+  {
+    if(Ellip.sweep)
+      fi += 10*M_PI/180;
+    else
+      fi -= 10*M_PI/180;
+
+    const float xR = Ellip.rx*cos(fi);
+    const float yR = Ellip.ry*sin(fi);
+  
+    Points[2*j] =   cx + cos_fi*xR - sin_fi*yR;
+    Points[2*j+1] = cy + sin_fi*xR + cos_fi*yR;
+  }
+  Points[2*i]=x2;	Points[2*i+1]=y2;
+  i++;
+  ClosePathLine(&Points,i,false,Tx);
+
+ return true;
+}
+
+
+/// When elliptic arc cannot be constructed, use plain line segment instead.
+bool TconvertedPass1_SVG::FakeEllipse(float x2, float y2, AbstractTransformXY *Tx, char CharPassed)
+{
+  if(fabs(PositionX-x2)<1e-5 && fabs(PositionY-y2)<1e-5) return true;
+  float *Points = (float*)malloc(4*sizeof(float));
+  if(!Points)
+  {
+    PositionX=x2; PositionY=y2;
+    return false;
+  }
+  Points[0]=PositionX;	Points[1]=PositionY;
+  Points[2]=x2;		Points[3]=y2;
+  int n = 2;
+  ClosePathLine(&Points,n,false,Tx);	// This sets PositionX and PositionY to [x2,y2]
+
+  if(err!=NULL)
+  {
+    perc.Hide();
+    fprintf(err,_("\nError: Path command '%c' is only partially supported!"),CharPassed);
+  }
+return true;
+}
+
+
 // https://developer.mozilla.org/en-US/docs/Web/SVG/Tutorial/Paths
 void TconvertedPass1_SVG::Path(void)
 {
@@ -1811,10 +1965,6 @@ float *Points = NULL;
 float val;
 int n, i;
 const char *StrMovements;
-float PositionOffsetX = 0;
-float PositionOffsetY = 0;
-//float ObjPositionX = PositionX;
-//float ObjPositionY = PositionY;
 bool isCurve = false;
 bool FirstCommand = true;
 char LastCommand = 0;
@@ -1847,42 +1997,28 @@ VectorList VectListIn;
         else
           ClosePathLine(&Points,n,false,Tx);
         {
-          float rx, ry, rotation, x, y;
-          char large_arc, sweep;
-          ReadFloat(&StrMovements, rx);
+          SvgEllipse Ellip;          
+          ReadFloat(&StrMovements, Ellip.rx);
           if(*StrMovements==',') StrMovements++;
-          ReadFloat(&StrMovements, ry);
+          ReadFloat(&StrMovements, Ellip.ry);
           if(*StrMovements==',') StrMovements++;
-          ReadFloat(&StrMovements, rotation);
+          ReadFloat(&StrMovements, Ellip.rotation);
           if(*StrMovements==',') StrMovements++;
           ReadFloat(&StrMovements, val);
+	  Ellip.large_arc = (val==0) ? 0 : 1;
           if(*StrMovements==',') StrMovements++;
-	  large_arc = (val==0) ? 0 : 1;
-          ReadFloat(&StrMovements, val);
+          ReadFloat(&StrMovements, val);          
+	  Ellip.sweep = (val==0) ? 0 : 1;
           if(*StrMovements==',') StrMovements++;
-	  sweep = (val==0) ? 0 : 1;
-          ReadFloat(&StrMovements, x);
+          ReadFloat(&StrMovements, Ellip.dx);
           if(*StrMovements==',') StrMovements++;
-          ReadFloat(&StrMovements, y);
+          ReadFloat(&StrMovements, Ellip.dy);
 
-          if(Points==NULL)
+          if(!SolveEllipse(Ellip, PositionX,PositionY, Ellip.dx,Ellip.dy, Tx))
           {
-            Points = (float*)malloc(4*sizeof(float));
-            if(!Points) goto ExitErr;
-            Points[0]=PositionX; Points[1]=PositionY;
-            Points[2]=x;         Points[3]=y;
-            n = 2;
-            ClosePathLine(&Points,n,false,Tx);
+            if(!FakeEllipse(Ellip.dx,Ellip.dy,Tx,'A')) goto ExitErr;
           }
-          else
-          {
-	    PositionX = x;
-	    PositionY = y;
-          }
-          //VectorEllipse *pVectCirc = new VectorEllipse(cy-r, cy+r, cx+r, cx-r);
         }
-        if(err!=NULL)
-            fprintf(err,_("\nError: Path command 'A' is only partially supported!"));
 	break;
 
       case 'a':		// A rx ry x-axis-rotation large-arc-flag sweep-flag dx dy  see https://www.nan.fyi/svg-paths/arcs
@@ -1892,42 +2028,28 @@ VectorList VectListIn;
         else
           ClosePathLine(&Points,n,false,Tx);
         {
-          float rx, ry, rotation, dx, dy;
-          char large_arc, sweep;
-          ReadFloat(&StrMovements, rx);
+          SvgEllipse Ellip;          
+          ReadFloat(&StrMovements, Ellip.rx);
           if(*StrMovements==',') StrMovements++;
-          ReadFloat(&StrMovements, ry);
+          ReadFloat(&StrMovements, Ellip.ry);
           if(*StrMovements==',') StrMovements++;
-          ReadFloat(&StrMovements, rotation);
+          ReadFloat(&StrMovements, Ellip.rotation);
           if(*StrMovements==',') StrMovements++;
           ReadFloat(&StrMovements, val);
+	  Ellip.large_arc = (val==0) ? 0 : 1;
           if(*StrMovements==',') StrMovements++;
-	  large_arc = (val==0) ? 0 : 1;
           ReadFloat(&StrMovements, val);
+	  Ellip.sweep = (val==0) ? 0 : 1;
           if(*StrMovements==',') StrMovements++;
-	  sweep = (val==0) ? 0 : 1;
-          ReadFloat(&StrMovements, dx);
+          ReadFloat(&StrMovements, Ellip.dx);
           if(*StrMovements==',') StrMovements++;
-          ReadFloat(&StrMovements, dy);
+          ReadFloat(&StrMovements, Ellip.dy);
 
-          if(Points==NULL)
+          if(!SolveEllipse(Ellip, PositionX,PositionY, PositionX+Ellip.dx,PositionY+Ellip.dy, Tx))
           {
-            Points = (float*)malloc(4*sizeof(float));
-            if(!Points) goto ExitErr;
-            Points[0]=PositionX;	Points[1]=PositionY;
-            Points[2]=PositionX+dx;	Points[3]=PositionX+dy;
-            n = 2;
-            ClosePathLine(&Points,n,false,Tx);
-          }
-          else
-          {
-	    PositionX += dx;
-	    PositionY += dy;
-          }
-          //VectorEllipse *pVectCirc = new VectorEllipse(cy-r, cy+r, cx+r, cx-r);
+            if(!FakeEllipse(PositionX+Ellip.dx,PositionY+Ellip.dy,Tx,'a')) goto ExitErr;
+          }          
         }
-        if(err!=NULL)
-            fprintf(err,_("\nError: Path command 'a' is only partially supported!"));
 	break;
 
       case 'M':			//move to.
@@ -1944,9 +2066,7 @@ VectorList VectListIn;
         {
           ReadFloat(&StrMovements, PositionY);
         }
-        PositionOffsetX = PositionOffsetY = 0;
-/*      ObjPositionX = PositionX;
-        ObjPositionY = PositionY; */
+        //PositionOffsetX = PositionOffsetY = 0;
         FirstCommand = false;
         break;
 
@@ -1956,31 +2076,28 @@ VectorList VectListIn;
           ClosePathCurve(&Points,n,false,Tx);
         else
           ClosePathLine(&Points,n,false,Tx);
-//        ObjPositionX = 0;
-//        ObjPositionY = 0;
 
-        ReadFloat(&StrMovements, PositionOffsetX);
+        ReadFloat(&StrMovements, val);
         if(FirstCommand)
-            PositionX = PositionOffsetX;
+            PositionX = val;
         else
         {
-          PositionX += PositionOffsetX;
-          PositionOffsetX = PositionX;
+          PositionX += val;
         }
 
         if(*StrMovements==',') StrMovements++;
         while(isspace(*StrMovements)) StrMovements++;
         if(isdigit(*StrMovements) || *StrMovements=='.' || *StrMovements=='-')
         {
-          ReadFloat(&StrMovements, PositionOffsetY);
+          ReadFloat(&StrMovements, val);
           if(FirstCommand)
-            PositionY = PositionOffsetY;
+            PositionY = val;
           else
           {
-            PositionY += PositionOffsetY;
-            PositionOffsetY = PositionY;
+            PositionY += val;
           }
         }
+        //PositionOffsetX = PositionOffsetY = 0;
         FirstCommand = false;
         break;
 
@@ -2009,8 +2126,8 @@ VectorList VectListIn;
 
         if(ReadFloat(&StrMovements, PositionX))
         {
-          Points[2*n-2] = PositionX + PositionOffsetX;
-          Points[2*n-1] = PositionY + PositionOffsetY;
+          Points[2*n-2] = PositionX;
+          Points[2*n-1] = PositionY;
         }
         break;
 
@@ -2068,19 +2185,19 @@ VectorList VectListIn;
 
           if(ReadFloat(&StrMovements, PositionY))
           {
-            Points[2*n-1] = PositionY + PositionOffsetY;
-            Points[2*n-2] = PositionX + PositionOffsetX;
+            Points[2*n-1] = PositionY;
+            Points[2*n-2] = PositionX;
           }
         break;
 
      case 'v':		// vertical relative line to.
-        LastCommand = 'v';
-        if(isCurve)
-        {
-          if(n>0) SegmentCount++;
-          ClosePathCurve(&Points,n,false,Tx);
-          isCurve = false;
-        }
+          LastCommand = 'v';
+          if(isCurve)
+          {
+            if(n>0) SegmentCount++;
+            ClosePathCurve(&Points,n,false,Tx);
+            isCurve = false;
+          }
 
           if(Points==NULL)
           {
@@ -2133,18 +2250,18 @@ VectorList VectListIn;
             ReadFloat(&StrMovements, Points[2*n-1]);
           }
           else
-            Points[2*n-1] = PositionY - PositionOffsetY;
+            Points[2*n-1] = PositionY /* - PositionOffsetY */;
 
 	  if(IsFinite(&Points[2*n-2]))
           {
-            Points[2*n-2] += PositionOffsetX;
+            //Points[2*n-2] += PositionOffsetX;
             PositionX = Points[2*n-2];
           }
           else
             Points[2*n-2] = PositionX;
           if(IsFinite(&Points[2*n-1]))
           {
-            Points[2*n-1] += PositionOffsetY;          
+            //Points[2*n-1] += PositionOffsetY;          
             PositionY = Points[2*n-1];
           }
           else
@@ -2225,12 +2342,12 @@ VectorList VectListIn;
             if(*StrMovements==',') StrMovements++;
             ReadFloat(&StrMovements, PointBase[-1]); // y - the end point for curve.
 
-            PointBase[-6] += PositionOffsetX;
+            /* PointBase[-6] += PositionOffsetX;
             PointBase[-4] += PositionOffsetX;
             PointBase[-2] += PositionOffsetX;
             PointBase[-5] += PositionOffsetY;
             PointBase[-3] += PositionOffsetY;
-            PointBase[-1] += PositionOffsetY;
+            PointBase[-1] += PositionOffsetY; */
          }
         break;
 
@@ -2272,12 +2389,12 @@ VectorList VectListIn;
             PointBase[-6] = SolveQuadraticPos(PointBase[-8], PointBase[-6]);
             PointBase[-5] = SolveQuadraticPos(PointBase[-7], PointBase[-5]);
 
-            PointBase[-6] += PositionOffsetX;
+            /* PointBase[-6] += PositionOffsetX;
             PointBase[-4] += PositionOffsetX;
             PointBase[-2] += PositionOffsetX;
             PointBase[-5] += PositionOffsetY;
             PointBase[-3] += PositionOffsetY;
-            PointBase[-1] += PositionOffsetY;
+            PointBase[-1] += PositionOffsetY; */
           }
         break;
 
@@ -2325,12 +2442,12 @@ VectorList VectListIn;
             PointBase[-3] = SolveQuadraticPos(PointBase[-1], val);
           }
 
-          PointBase[-6] += PositionOffsetX;
+          /* PointBase[-6] += PositionOffsetX;
           PointBase[-4] += PositionOffsetX;
           PointBase[-2] += PositionOffsetX;
           PointBase[-5] += PositionOffsetY;
           PointBase[-3] += PositionOffsetY;
-          PointBase[-1] += PositionOffsetY;
+          PointBase[-1] += PositionOffsetY; */
         }
         break;
 
@@ -2458,6 +2575,7 @@ VectorList VectListIn;
           ReadFloat(&StrMovements, PointBase[-4]);
           if(*StrMovements==',') StrMovements++;
           ReadFloat(&StrMovements, PointBase[-3]);
+          if(*StrMovements==',') StrMovements++;
           ReadFloat(&StrMovements, PointBase[-2]);
           if(*StrMovements==',') StrMovements++;
           ReadFloat(&StrMovements, PointBase[-1]);
@@ -2504,6 +2622,7 @@ VectorList VectListIn;
             if(*StrMovements==',') StrMovements++;
             ReadFloat(&StrMovements, PointBase[-3]);
             PointBase[-3] += PositionY;
+            if(*StrMovements==',') StrMovements++;
             ReadFloat(&StrMovements, PointBase[-2]);
             PointBase[-2] += PositionX;
             if(*StrMovements==',') StrMovements++;
@@ -2631,7 +2750,10 @@ VectorList VectListIn;
         else
         {
           if(err!=NULL)
-              fprintf(err,_("\nError: Unsupported path command '%c' in SVG path!"),ch);
+          {
+            perc.Hide();
+            fprintf(err,_("\nError: Unsupported path command '%c' in SVG path!"),ch);
+          }
         }
         break;
 
@@ -2835,13 +2957,14 @@ void TconvertedPass1_SVG::Defs(void)
 int i;
 FloatBBox bbxBk = bbx;	// Defines should not update current bounding box.
 
+  if(subby==XML_closedtag) goto Finish;
   InitBBox(bbx);
   recursion++;
   while(!feof(wpd))
   {
     ReadXMLTag(false);
 
-    if(by==XML_tag && TAG=="<clipPath>")
+    if((by==XML_tag||by==XML_closedtag) && TAG=="<clipPath>")
     {
       DefinedObject *pDefObj = NULL;
       if((i=TAG_Args IN "id") >= 0)
@@ -2859,22 +2982,25 @@ FloatBBox bbxBk = bbx;	// Defines should not update current bounding box.
           }
         }
       }
-      recursion++;
-      while(!feof(wpd))
+      if(by==XML_tag)
       {
-        if(pDefObj) VectList.Swap(pDefObj->VectList);
-        ProcessKeySVG();
-        if(pDefObj) VectList.Swap(pDefObj->VectList);
-        ReadXMLTag(false);
+        recursion++;
+        while(!feof(wpd))
+        {
+          if(pDefObj) VectList.Swap(pDefObj->VectList);
+          ProcessKeySVG();
+          if(pDefObj) VectList.Swap(pDefObj->VectList);
+          ReadXMLTag(false);
 
-        if(by==XML_closetag && (TAG=="</defs>" || TAG=="</clipPath>"))
-            break;
+          if((by==XML_closetag||by==XML_closedclosetag) && (TAG=="</defs>" || TAG=="</clipPath>"))
+              break;
+        }
       }
       recursion--;
       if(pDefObj) AddDefine(pDefObj);
     }
 
-    if(by==XML_tag && (TAG=="<linearGradient>" || TAG=="<radialGradient>"))
+    if((by==XML_tag||by==XML_closedtag) && (TAG=="<linearGradient>" || TAG=="<radialGradient>"))
     {
       DefinedObject *pDefObj = NULL;
       if((i=TAG_Args IN "id") >= 0)
@@ -2893,32 +3019,35 @@ FloatBBox bbxBk = bbx;	// Defines should not update current bounding box.
         }
       }
 
-      recursion++;
-      while(!feof(wpd))
+      if(by==XML_tag)
       {
-        if(pDefObj) VectList.Swap(pDefObj->VectList);
-        ProcessKeySVG();
-        if(pDefObj) VectList.Swap(pDefObj->VectList);
-        ReadXMLTag(false);
+        recursion++;
+        while(!feof(wpd))
+        {
+          if(pDefObj) VectList.Swap(pDefObj->VectList);
+          ProcessKeySVG();
+          if(pDefObj) VectList.Swap(pDefObj->VectList);
+          ReadXMLTag(false);
 
-        if(by==XML_closetag && (TAG=="</defs>" || TAG=="</linearGradient>" || TAG=="</radialGradient>"))
-            break;
-        if(by==XML_tag && TAG=="<stop>")
-        {          
-          if(GetColor(pDefObj->FillColor, "stop-color") == 1)
+          if((by==XML_closetag||by==XML_closedclosetag) && (TAG=="</defs>" || TAG=="</linearGradient>" || TAG=="</radialGradient>"))
+              break;
+          if((by==XML_tag||by==XML_closedtag) && TAG=="<stop>")
           {          
-            pDefObj->PropsSet |= DefinedObject::EpropFillColor;
-            //if((i=TAG_Args IN "offset") >= 0)		// @TODO: Gradient is not supported yet.
-            //{
-            //}
+            if(GetColor(pDefObj->FillColor, "stop-color") == 1)
+            {          
+              pDefObj->PropsSet |= DefinedObject::EpropFillColor;
+              //if((i=TAG_Args IN "offset") >= 0)		// @TODO: Gradient is not supported yet.
+              //{
+              //}
+            }
           }
         }
+        recursion--;
       }
-      recursion--;
       if(pDefObj) AddDefine(pDefObj);
     }
 
-    if(by==XML_closetag && TAG=="</defs>")
+    if((by==XML_closetag||by==XML_closedclosetag) && TAG=="</defs>")
         break;
 
     if((i=TAG_Args IN "id") >= 0)
@@ -2941,6 +3070,11 @@ FloatBBox bbxBk = bbx;	// Defines should not update current bounding box.
       }
     }
 
+    if(TAG=="<style>")
+    {
+      Style();			// style could be nested inside defs.
+    }
+
     const unsigned char BkFlag=flag;
     flag = Nothing;		// Prevent to expand anything inside Defs.
     ProcessKeySVG();
@@ -2948,7 +3082,7 @@ FloatBBox bbxBk = bbx;	// Defines should not update current bounding box.
   }
   recursion--;
   bbx = bbxBk;
-
+Finish:
   strcpy(ObjType,"Defs");
 }
 
@@ -3062,6 +3196,8 @@ uint8_t by, subby;
 	       break;
 
 	case XML_tag:
+        case XML_closedtag:
+               subby=by;
                loc_TAG = copy(TAG,1,length(TAG)-2);	//Normal tag <xxx>
 	       if((tag=loc_TAG())==NULL) break;
 
@@ -3082,6 +3218,8 @@ uint8_t by, subby;
 	       if(loc_TAG=="style")   {by=SVG_STYLE;break;}
 	       break;
 	case XML_closetag:
+        case XML_closedclosetag:
+               subby=by;
                loc_TAG = copy(TAG,2,length(TAG)-3);	//Closing tag </xxx>
 	       if((tag=loc_TAG())==NULL) break;
 	       if(loc_TAG=="defs")    {by=SVG_DEFS;break;}
