@@ -78,36 +78,37 @@ Flags:'h';       Hard return
 		  1 Valid character placed on the line */
 
 /*WP2LaTex switches: -1:disabled; 0:automatically enabled; 1: forced to enable*/
-int8_t   Accents = STYLE_NOTUSED,
-	AmsMath = -1,
-        Amssymb = -1,		// Totaly Disabled
+int8_t  Accents = STYLE_NOTUSED,
+	AmsMath = STYLE_DISABLED,
+        Amssymb = STYLE_DISABLED,
         arabtex = STYLE_NOTUSED,
-	Arevmath = -1,		// Totaly Disabled
+	Arevmath = STYLE_DISABLED,
         Cyrillic = STYLE_NOTUSED,
 	cjHebrew = STYLE_NOTUSED,
-	colors = STYLE_NOTUSED,	// Only for LaTex 2.0e
-	textcomp = -1,
+	colors = STYLE_NOTUSED,			// Only for LaTex 2.0e
+	textcomp = STYLE_NOTUSED,
 	EndNotes = STYLE_NOTUSED,
-	FancyHdr = -1,
-	Columns = 1,		// -1 disabled; 0 auto two; 1 auto multi; 2 forced two; >2 forced multi*/
-	InputPS = IMG_graphicx,	// -1 disabled; 0 auto InputPS.sty; 1 InputPS.sty; 2 auto graphicx.sty; 3 graphicx.sty; 4 auto epsfig.sty; 5 epsfig.sty; 8 auto graphics.sty; 9 graphics.sty;
+	FancyHdr = STYLE_DISABLED,
 	pifont = STYLE_NOTUSED,
 	PostScript = STYLE_NOTUSED,
-	MakeIdx = -1,
-	Wasy = -1,		// Totaly Disabled	
+	MakeIdx = STYLE_DISABLED,
+	Wasy = STYLE_DISABLED,
 	LaTeXsym = 0,
-	Bbm = -1,
-	TIPA = -1,
-	fontenc = -1,
-	Rsfs = -1,
+	Bbm = STYLE_DISABLED,
+	TIPA = STYLE_DISABLED,
+	fontenc = STYLE_DISABLED,
+	Rsfs = STYLE_DISABLED,
 	Ulem = 0,		// Enabled on demand
 	rus_yo = 0,
-	LongTable = -1,
-	SaveWPG = -1,
+	LongTable = STYLE_DISABLED,
         Rotate = STYLE_NOTUSED,
         Scalerel = STYLE_NOTUSED,
         mxedruli = STYLE_NOTUSED,
 	LineNo = STYLE_NOTUSED;
+		// special handling
+int8_t	Columns = 1,		// -1 disabled; 0 auto two; 1 auto multi; 2 forced two; >2 forced multi
+	InputPS = IMG_graphicx;	// -1 disabled; 0 auto InputPS.sty; 1 InputPS.sty; 2 auto graphicx.sty; 3 graphicx.sty; 4 auto epsfig.sty; 5 epsfig.sty; 8 auto graphics.sty; 9 graphics.sty;
+int8_t	SaveWPG = -1;
 bool Index = false,
         Interactive = true,
 	NFSS = false,
@@ -188,6 +189,7 @@ const TStyleOpCl StyleOpCl2[] =
   {"\\begin{cjhebrew}", "\\end{cjhebrew}", NULL, NULL},
   {"\\begin{linenumbers}", "\\end{linenumbers}", NULL, NULL},
   {"\\mxedc ", "", NULL, NULL},
+  {"\\begin{RLtext}", "\\end{RLtext}", NULL, NULL}
 };
 
 
@@ -225,6 +227,7 @@ const TStyleOpCl StyleOpCl3[] =
   {"\\begin{cjhebrew}", "\\end{cjhebrew}", NULL, NULL},
   {"\\begin{linenumbers}", "\\end{linenumbers}", NULL, NULL},
   {"\\mxedc ", "", NULL, NULL},
+  {"\\begin{RLtext}", "\\end{RLtext}", NULL, NULL}
 };
 
 
@@ -1543,42 +1546,43 @@ typedef struct
 /** Package list with command line switches. */
 static const PkgItem PkgList[] = 
 	{{"accents",&Accents, N_("Use accents to support additional accents.")},
-        {"amssymb",&Amssymb,NULL},
-        {"Amssymb",&Amssymb, N_("Use AMSsymb with special characters.")},
+	{"amssymb",&Amssymb,NULL},
+	{"Amssymb",&Amssymb, N_("Use AMSsymb with special characters.")},
+	{"arabtex",&arabtex, N_("Use arabtex.sty to support arrabic glyphs.")},
 	{"arevmath",&Arevmath,NULL},
-        {"Arevmath",&Arevmath, N_("Use arevmath with special characters.")},
-        {"amsmath",&AmsMath,NULL},
-        {"AmsMath",&AmsMath, N_("Use AmsMath with special characters.")},
-        {"bbm",&Bbm,NULL},
-        {"Bbm",&Bbm, N_("Use Bbm with special characters.")},
-        {"cjhebrew",&cjHebrew}, {"cjHebrew",&cjHebrew},
-        {"cyrillic",&Cyrillic,NULL},
-        {"Cyrillic",&Cyrillic, N_("Use cyrillic.sty to support cyrillic script.")},
-        {"endnotes",&EndNotes,NULL},
-        {"Endnotes",&EndNotes},
-        {"fancyhdr",&FancyHdr}, {"Fancyhdr",&FancyHdr},   {"FancyHdr",&FancyHdr},
-        {"fontenc-T1",&fontenc, NULL},
-        {"FontEnc-T1",&fontenc, N_("Use package fontenc.sty [T1] with additional characters")},
-        {"LaTeXsym",&LaTeXsym,NULL},
-        {"latexsym",&LaTeXsym, N_("Use latexsym with special characters.")},
-        {"LineNo", &LineNo,NULL},
-        {"lineno", &LineNo},
-        {"longtable",&LongTable,NULL},
-        {"LongTable",&LongTable, N_("Use longtable for better tables.")},
-        {"makeidx",&MakeIdx,NULL},   
-        {"MakeIdx",&MakeIdx, N_("Use makeidx for placing index.")},
-        {"mxedruli",&mxedruli, N_("Use mxedruli for Georgia characters.")},
-        {"pifont",&pifont,NULL},
-        {"PiFont",&pifont, N_("Use additional package pifont.")},
-        {"rsfs",&Rsfs,NULL},
-        {"Rsfs",&Rsfs, N_("Use mathrsfs with special characters.")},
-        {"scalerel",&Scalerel, N_("Use additional package scalerel.")},
-        {"tipa",&TIPA,NULL},
-        {"TIPA",&TIPA, N_("Use TIPA.sty for IPA and other phonetic characters")},
-        {"ulem",&Ulem,NULL},
-        {"Ulem",&Ulem, N_("Use ulem for underlining and striking out.")},
-        {"wasy",&Wasy,NULL},
-        {"Wasy",&Wasy,N_("Use Wasy2 with special characters.")}};
+	{"Arevmath",&Arevmath, N_("Use arevmath with special characters.")},
+	{"amsmath",&AmsMath,NULL},
+	{"AmsMath",&AmsMath, N_("Use AmsMath with special characters.")},
+	{"bbm",&Bbm,NULL},
+	{"Bbm",&Bbm, N_("Use Bbm with special characters.")},
+	{"cjhebrew",&cjHebrew}, {"cjHebrew",&cjHebrew},
+	{"cyrillic",&Cyrillic,NULL},
+	{"Cyrillic",&Cyrillic, N_("Use cyrillic.sty to support cyrillic script.")},
+	{"endnotes",&EndNotes,NULL},
+	{"Endnotes",&EndNotes},
+	{"fancyhdr",&FancyHdr}, {"Fancyhdr",&FancyHdr},   {"FancyHdr",&FancyHdr},
+	{"fontenc-T1",&fontenc, NULL},
+	{"FontEnc-T1",&fontenc, N_("Use package fontenc.sty [T1] with additional characters")},
+	{"LaTeXsym",&LaTeXsym,NULL},
+	{"latexsym",&LaTeXsym, N_("Use latexsym with special characters.")},
+	{"LineNo", &LineNo,NULL},
+	{"lineno", &LineNo},
+	{"longtable",&LongTable,NULL},
+	{"LongTable",&LongTable, N_("Use longtable for better tables.")},
+	{"makeidx",&MakeIdx,NULL},   
+	{"MakeIdx",&MakeIdx, N_("Use makeidx for placing index.")},
+	{"mxedruli",&mxedruli, N_("Use mxedruli for Georgia characters.")},
+	{"pifont",&pifont,NULL},
+	{"PiFont",&pifont, N_("Use additional package pifont.")},
+	{"rsfs",&Rsfs,NULL},
+	{"Rsfs",&Rsfs, N_("Use mathrsfs with special characters.")},
+	{"scalerel",&Scalerel, N_("Use additional package scalerel.")},
+	{"tipa",&TIPA,NULL},
+	{"TIPA",&TIPA, N_("Use TIPA.sty for IPA and other phonetic characters")},
+	{"ulem",&Ulem,NULL},
+	{"Ulem",&Ulem, N_("Use ulem for underlining and striking out.")},
+	{"wasy",&Wasy,NULL},
+	{"Wasy",&Wasy,N_("Use Wasy2 with special characters.")}};
 
 
 static char StyleUsed(int8_t *u)
@@ -1602,7 +1606,7 @@ void PrintPackageList(void)
 
 
 /// See which CPs are supported by inputenc: https://ctan.math.illinois.edu/macros/latex/base/inputenc.pdf
-const TOutCodePage OutCodepages[11] =
+const TOutCodePage OutCodepages[12] =
 {
   {"852", "internalTOcp852", 852, true},
   {"866", NULL, 866, false},
@@ -1614,10 +1618,31 @@ const TOutCodePage OutCodepages[11] =
   {"ISO8859-2", "internalTOiso_8859_2", ISO8859_2, true},
   {"ISO-8859-2", "internalTOiso_8859_2", ISO8859_2, true},
   {"KOI8R", NULL, KOI8R, false},
-  {"UTF8", "internalTOunicode", UTF8, true}
+  {"UTF8", "internalTOunicode", UTF8, true},
+  {"UTF-8", "internalTOunicode", UTF8, true}
 };
 
 
+void ShowHelpImages(void)
+{
+TImageFileHandler *LoadPicture_XXX;
+
+  fprintf(err, _("Supported image formats:\n"));
+  for(LoadPicture_XXX=TImageFileHandler::first();LoadPicture_XXX!=NULL;LoadPicture_XXX=LoadPicture_XXX->next())
+  {
+    fprintf(err, "%s%s%s %s%s; ",LoadPicture_XXX->extension(),
+			LoadPicture_XXX->description()==NULL?"":"#",
+			LoadPicture_XXX->description()==NULL?"":LoadPicture_XXX->description(),
+			LoadPicture_XXX->LoadPicture==NULL?"":"R",
+			LoadPicture_XXX->SavePicture==NULL?"":"W");
+    if(LoadPicture_XXX->Flags & FILE_FORMAT_CAP_EXIF) fputs("+EXIF",err);
+    //if(LoadPicture_XXX->Flags & FILE_FORMAT_256_COLORS) printf("-MAX256Colors");
+    if(LoadPicture_XXX->Flags & FILE_FORMAT_DUPLICATE) fputs(_("(duplicated)"),err);
+    printf("\n");
+  }
+}
+
+
 /** This procedure handles parameters and the filenames*/
 int CommandLine(int argc, char *argv[])
 {
@@ -1682,11 +1707,11 @@ int p;
 		if(OutCodepages[i].Translator)
 		  Convert2Target = GetTranslator(OutCodepages[i].Translator);
 		CPStyles = OutCodepages[i].UseCpStyles;
-                break;	      
+                break;
                 }
 	      }
-          if(i<=sizeof(OutCodepages)/sizeof(OutCodePage)) continue;	// Output codepage has been found.
-	  
+          if(i<sizeof(OutCodepages)/sizeof(TOutCodePage)) continue;	// Output codepage has been found.
+
 	  if(!strcmp(name, "Styles") || !strcmp(name, "styles"))
 	     {
 	     CPStyles = true;
@@ -2078,10 +2103,10 @@ int p;
 		FFormatTranslator *Fx;
 		Fx = FFormatTranslator::first();
 		while(Fx!=NULL)
-		  {
+		{
 		  fprintf(err, (Fx->next()==NULL)?"%s":"%s,", Fx->shortkey());
 		  Fx = Fx->next();
-		  }
+		}
 		fprintf(err,")\n");
 		TImageFileHandler *LoadPicture_XXX;
 	        fprintf(err,_("  Supported Image formats:"));
@@ -2093,7 +2118,22 @@ int p;
 		         LoadPicture_XXX->SavePicture==NULL?"":"W",
                          LoadPicture_XXX->next()==NULL?"":"; ");
 		    }
-	        fprintf(err,"\n");
+                fprintf(err,_("\n  Supported code pages:"));
+                CpTranslator *Ptrn = CpTranslator::getFirst();
+                while(Ptrn!=NULL)
+                {
+                  if(Ptrn->Name)
+                  {
+                    const char *ToS = strstr(Ptrn->Name,"TOinternal");
+                    if(ToS)
+                    {
+                      const string str(Ptrn->Name,ToS-Ptrn->Name);
+                      fprintf(err," %s",str());
+                    }
+                  }
+                  Ptrn = Ptrn->getNext();
+                }
+                fprintf(err,"\n");
 #ifdef CORELEFT
 		fprintf(err,"  free memory %ld\n",CORELEFT());
 #endif
@@ -2112,6 +2152,10 @@ int p;
            CheckGettext(argv==NULL?NULL:*argv, "wp2latex");
 #endif
 	   Heading();
+           if(CheckArg(p,argc,argv[p]))
+           {
+             if(!strcmp(argv[p],"images")) {ShowHelpImages();RunError(-2);return(0);}
+           }
 	   ShowHelp();
 	   RunError(-2); return(0);
 	   }
