@@ -35,7 +35,7 @@
 
 //Non standard include files
 #include "stringa.h"
-#include <lists.h>
+#include "lists.h"
 #include "wp2latex.h"
 
 #ifdef _MSC_VER
@@ -321,7 +321,7 @@ static bool printed=false;
 
  if(Verbosing < 1) return;
  printf(_("\n>>>WP2LaTeX<<< Conversion program: From Wordperfect to LaTeX Version %s \n"
-	  "  (c) Made by J.Fojtik  ---- Date : 1996-2024\n"),
+	  "  (c) Made by J.Fojtik  ---- Date : 1996-2025\n"),
 	    VersionWP2L);
 }
 
@@ -416,7 +416,7 @@ void ShowHelp(void)
 
 void ShowCopyright(void)
 {
-  puts(_("\nThis program and related files are copyright (c) 1996-2024 Fojtik Jaroslav."
+  puts(_("\nThis program and related files are copyright (c) 1996-2025 Fojtik Jaroslav."
 	 "\nThis code can be redistributed and/or modified under the terms of the GNU"
 	 "\nGeneral Public License available from: http://www.gnu.org/copyleft/gpl.html."
 	 "\nWith one additional requirement:"
@@ -440,7 +440,8 @@ void ShowCopyright(void)
          "\nOr you may wish to edit the WordPerfect document to remove unwanted"
          "\ncodes (such as Tab, Tab Set), then run it through wp2latex again."));
 
-  puts(_("\nThanks to:R.C.Houtepen            for initial WP2LaTeX pascal release (1990)"
+  puts(_("\nThanks to:Compile farm project    for possibility to test on CPU architectures"
+         "\n          R.C.Houtepen            for initial WP2LaTeX pascal release (1990)"
 	 "\n          Rafael Rodriguez Pappa  for several notes and bugfixes"
 	 "\n          Damil Cavar             for several bugreports"
 	 "\n          Hilmar Preusse          for translating several WP extended chars; creating"
